@@ -1,7 +1,7 @@
 // qmidictlMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1010,7 +1010,7 @@ void qmidictlMainForm::aboutSlot (void)
 	QString sText = "<h1>" QMIDICTL_TITLE "</h1>\n";
 	sText += "<p>" + tr(QMIDICTL_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
-	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
+	sText += tr("Version") + ": <b>" PROJECT_VERSION "</b><br />\n";
 //	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 #ifdef CONFIG_DEBUG
 	sText += "<small><font color=\"red\">";
@@ -1032,6 +1032,7 @@ void qmidictlMainForm::aboutSlot (void)
 	sText += tr("This program is free software; you can redistribute it and/or modify it") + '\n';
 	sText += tr("under the terms of the GNU General Public License version 2 or later.");
 	sText += "</small>";
+	sText += "<br />\n";
 	sText += "</p>\n";
 
 	QMessageBox::about(this, tr("About"), sText);
